@@ -34,10 +34,6 @@ class Worker(Isolate):
         self._configure(*args, **kwargs)
         self._configured = True
 
-    @inject
-    async def on_store_update(self, event: StoreUpdateEvent, app_container=Provide["<container>"]):
-        await app_container.store().set_item(event.key, event.value)
-
     def _configure(self, *args, **kwargs):
         pass
 
